var _div, _div2, _div3, _TruncateList, _TruncateList2, _div4, _div5, _div6, _div7, _div8, _div9, _TruncateList3;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, waitFor } from '@testing-library/react';
import { vi } from 'vitest';
import '@testing-library/jest-dom';

// eslint-disable-next-line no-restricted-imports
import { generateA11yTests } from '@instructure/ui-scripts/lib/test/generateA11yTests';
import { runAxeCheck } from '@instructure/ui-axe-check';
import { TruncateList } from '../index';
import TruncateListExamples from '../__examples__/TruncateList.examples';
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
describe('<TruncateList />', () => {
  it('should return ref with elementRef prop', async () => {
    const elementRef = vi.fn();
    const _render = render(_jsxs(TruncateList, {
        elementRef: elementRef,
        children: [_div || (_div = _jsx("div", {
          children: "Item 1"
        })), _div2 || (_div2 = _jsx("div", {
          children: "Item 2"
        })), _div3 || (_div3 = _jsx("div", {
          children: "Item 3"
        }))]
      })),
      container = _render.container;
    const list = container.querySelector('ul[class$="-truncateList"]');
    await waitFor(() => {
      expect(elementRef).toHaveBeenCalledWith(list);
    });
  });
  it('should render <ul> and <li> items', async () => {
    const _render2 = render(_TruncateList || (_TruncateList = _jsxs(TruncateList, {
        children: [_jsx("div", {
          children: "Item 1"
        }), _jsx("div", {
          children: "Item 2"
        }), _jsx("div", {
          children: "Item 3"
        })]
      }))),
      container = _render2.container;
    const list = container.querySelector('[class$="-truncateList"]');
    const items = container.querySelectorAll('[class$="truncateList__listItem"]');
    expect(list).toBeInTheDocument();
    expect(list === null || list === void 0 ? void 0 : list.tagName).toBe('UL');
    expect(items.length).toBe(3);
    items.forEach(item => {
      expect(item.tagName).toBe('LI');
    });
  });
  it('should render only `visibleItemsCount` items', async () => {
    const _render3 = render(_TruncateList2 || (_TruncateList2 = _jsxs(TruncateList, {
        visibleItemsCount: 2,
        children: [_jsx("div", {
          children: "Item 1"
        }), _jsx("div", {
          children: "Item 2"
        }), _jsx("div", {
          children: "Item 3"
        })]
      }))),
      container = _render3.container;
    const list = container.querySelector('ul[class$="-truncateList"]');
    const items = container.querySelectorAll('[class$="truncateList__listItem"]');
    expect(items.length).toBe(2);
    expect(list).not.toHaveTextContent('Item 3');
  });
  describe('renderHiddenItemMenu', () => {
    it('should render element', async () => {
      const _render4 = render(_jsxs(TruncateList, {
          visibleItemsCount: 2,
          renderHiddenItemMenu: () => _div4 || (_div4 = _jsx("div", {
            id: "trigger",
            children: "trigger label"
          })),
          children: [_div5 || (_div5 = _jsx("div", {
            children: "Item 1"
          })), _div6 || (_div6 = _jsx("div", {
            children: "Item 2"
          })), _div7 || (_div7 = _jsx("div", {
            children: "Item 3"
          })), _div8 || (_div8 = _jsx("div", {
            children: "Item 4"
          })), _div9 || (_div9 = _jsx("div", {
            children: "Item 3"
          }))]
        })),
        container = _render4.container;
      const trigger = container.querySelector('[id="trigger"]');
      expect(trigger).toHaveTextContent('trigger label');
    });
  });
  describe('should be accessible', () => {
    it('a11y', async () => {
      const _render5 = render(_TruncateList3 || (_TruncateList3 = _jsx(TruncateList, {}))),
        container = _render5.container;
      const axeCheck = await runAxeCheck(container);
      expect(axeCheck).toBe(true);
    });
    describe('should be accessible with generated examples', () => {
      const generatedComponents = generateA11yTests(TruncateList, TruncateListExamples);
      it.each(generatedComponents)('should be accessible with example: $description', async ({
        content
      }) => {
        const _render6 = render(content),
          container = _render6.container;
        const axeCheck = await runAxeCheck(container);
        expect(axeCheck).toBe(true);
      });
    });
  });
});